diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Instrument.java @ 18130:b4e38f4ca414

Truffle: rename @SlowPath to @TruffleBoundary.
author Christian Humer <christian.humer@gmail.com>
date Tue, 21 Oct 2014 00:22:51 +0200
parents 8c34e2cc4add
children 85cec9cab17b
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Instrument.java	Tue Oct 21 00:22:48 2014 +0200
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/instrument/Instrument.java	Tue Oct 21 00:22:51 2014 +0200
@@ -25,7 +25,7 @@
 package com.oracle.truffle.api.instrument;
 
 import com.oracle.truffle.api.CompilerDirectives.CompilationFinal;
-import com.oracle.truffle.api.CompilerDirectives.SlowPath;
+import com.oracle.truffle.api.CompilerDirectives.TruffleBoundary;
 import com.oracle.truffle.api.frame.*;
 import com.oracle.truffle.api.instrument.impl.*;
 import com.oracle.truffle.api.nodes.*;
@@ -49,7 +49,7 @@
  * <li>Minimize computation in standard execution paths.</li>
  * <li>If runtime calls must be made back to a tool, construct the instrument with a callback stored
  * in a {@code final} field.</li>
  * <li>Tool methods called by the instrument should be annotated as {@link SlowPath} to prevent them
  * from being inlined into fast execution paths.</li>
  * <li>If computation in the execution path is needed, and if performance is important, then the
  * computation is best expressed as a guest language AST and evaluated using standard Truffle
@@ -49,7 +49,7 @@
  * <li>If runtime calls must be made back to a tool, construct the instrument with a callback stored
  * in a {@code final} field.</li>
- * <li>Tool methods called by the instrument should be annotated as {@link SlowPath} to prevent them
+ * <li>Tool methods called by the instrument should be annotated as {@link TruffleBoundary} to prevent them
  * from being inlined into fast execution paths.</li>
  * <li>If computation in the execution path is needed, and if performance is important, then the